import { sha1, sha256, sha384, sha512 } from 'crypto-hash';
import { GetLeetcodeProgressOptions, LeetcodeProgress, ProgressType } from './leetcode';
declare global {
    interface CacheStorage {
        default: Cache;
    }
}
declare const HASH_ALGORITHMS: {
    sha1: typeof sha1;
    sha256: typeof sha256;
    sha384: typeof sha384;
    sha512: typeof sha512;
};
export declare type RequestHandler = (event: FetchEvent) => Promise<Response | void>;
export declare type HashAlgorithm = keyof typeof HASH_ALGORITHMS;
export interface NormalizeURLOptions {
    progressType?: ProgressType;
}
export interface ProcessHeadersOptions {
    cors?: boolean;
    cacheTTL?: number;
}
export interface ComputeEtagOptions {
    hashAlgorithm?: HashAlgorithm;
}
export interface PrepareOptions extends NormalizeURLOptions {
    userlist?: Set<string>;
}
export interface HandleGetOptions extends GetLeetcodeProgressOptions, NormalizeURLOptions, ProcessHeadersOptions, ComputeEtagOptions, PrepareOptions {
    userlist?: Set<string>;
    cacheName?: string;
}
export interface HandlerContext {
    url: string;
    username: string;
    progressType: ProgressType;
}
export declare type CacheMatch = (url: string, headers: Headers) => Promise<Response | undefined>;
export declare type CachePut = (response: Response) => Promise<void>;
/**
 * @todo Hotfix the typing of R.pipeWith which currently
 * can only accept unary functions.
 *
 * Affected keywords:
 * - ProcessResponse
 * - UnaryFetchProgress
 * - processResponse
 */
export declare type ProcessResponse = (username: string, progressType: ProgressType) => Promise<Response>;
export declare type UnaryFetchProgress = (username: string) => Promise<LeetcodeProgress>;
/**
 * Leetcode: The username must contain only letters, numbers, hyphens
 * and underscores.
 */
export declare function validateUsername(username: unknown): username is string;
export declare function validateProgressType(progressType: unknown): progressType is ProgressType;
export declare function normalizeURL(url: string, { progressType }?: NormalizeURLOptions): URL;
export declare function prepare(request: Request, { progressType, userlist }?: PrepareOptions): HandlerContext;
export declare function useCache(cache: Cache | Promise<Cache>): [CacheMatch, CachePut];
export declare function createResponse(content: string): Response;
export declare function computeEtag(content: string, { hashAlgorithm }?: {
    hashAlgorithm?: HashAlgorithm;
}): Promise<string>;
export declare function processEtagHeader(response: Response, etagPromise: Promise<string>): Promise<Response>;
export declare function processHeaders(response: Response, { cors, cacheTTL }?: ProcessHeadersOptions): Response;
export declare function createGetHandler({ cacheName, cacheTTL, cors, hashAlgorithm, leetcodeGraphqlUrl, progressType, userlist, fetch, }?: HandleGetOptions): RequestHandler;
export {};
